Strategy Guides
===============

In-depth explanations of the trading strategies available in quaver,
including the financial background, signal logic, and tuning parameters.

.. toctree::
   :maxdepth: 2

   mean_reversion
   regime_mean_reversion
   vsa_stopping_volume
   breakout_consolidation
   pullback_trend
   reversial_support